@@ -1,4 +1,4 @@
-/* xscreensaver, Copyright © 2006-2021 Jamie Zawinski <jwz@jwz.org>
+/* xscreensaver, Copyright © 2006-2022 Jamie Zawinski <jwz@jwz.org>
  *
  * Permission to use, copy, modify, distribute, and sell this software and its
  * documentation for any purpose is hereby granted without fee, provided that
@@ -10,6 +10,8 @@
  *
  * This is a subclass of NSSlider that is flipped horizontally:
  * the high value is on the left and the low value is on the right.
+ *
+ * It also implements ratio sliders, where 1.0 is forced to the middle.
  */
 
 #ifdef HAVE_IPHONE
@@ -18,6 +20,8 @@
 # define NSRect   CGRect
 # define minValue minimumValue
 # define maxValue maximumValue
+# define setMinValue setMinimumValue
+# define setMaxValue setMaximumValue
 #else
 # import <Cocoa/Cocoa.h>
 #endif
@@ -27,14 +31,20 @@
 @interface InvertedSlider : NSSlider
 {
   BOOL inverted;
+  BOOL ratio;
   BOOL integers;
   double increment;
+  double origMaxValue;
+  double origMinValue;
 }
 
 - (double) increment;
 - (void) setIncrement:(double)v;
 
-- (id) initWithFrame:(NSRect)r inverted:(BOOL)_inv integers:(BOOL)_int;
+- (id) initWithFrame:(NSRect)r
+            inverted:(BOOL)_inv
+               ratio:(BOOL)_ratio
+            integers:(BOOL)_int;
 
 # ifdef HAVE_IPHONE
 - (double) transformedValue;
