@@ -36,10 +36,9 @@
 "*textURL:		https://en.wikipedia.org/w/index.php?title=Special:NewPages&feed=rss",
 "*demoCommand: xscreensaver-settings",
 "*helpURL: https://www.jwz.org/xscreensaver/man.html",
-"*loadURL: gnome-open '%s'",
-"*manualCommand: yelp man:%s || \
-			x-terminal-emulator -t '%s manual' \
-			  -e /bin/sh -c \"man %s; read foo\"",
+"*loadURL: x-www-browser '%s' || firefox '%s' || chromium-browser '%s'",
+"*manualCommand: lxterminal -T '%s manual' \
+		    -e /bin/sh -c 'man \"%s\" ; read foo'",
 "*dateFormat:		%I:%M %p, %a %b %e",
 "*newLoginCommand:	no-such-login-manager",
 "XScreenSaver.pointerHysteresis:		10",
@@ -179,254 +178,264 @@
 "*errorFont:  sans-serif bold 18",
 "*errorColor: #FF0000",
 "*programs:								      \
-				maze -root				    \\n\
-  GL: 				superquadrics -root			    \\n\
-				attraction -root			    \\n\
-				blitspin -root				    \\n\
-				greynetic -root				    \\n\
-				helix -root				    \\n\
-				hopalong -root				    \\n\
-				imsmap -root				    \\n\
--				noseguy -root				    \\n\
--				pyro -root				    \\n\
-				qix -root				    \\n\
--				rocks -root				    \\n\
-				rorschach -root				    \\n\
-				decayscreen -root			    \\n\
-				flame -root				    \\n\
-				halo -root				    \\n\
-				slidescreen -root			    \\n\
-				pedal -root				    \\n\
-				bouboule -root				    \\n\
--				braid -root				    \\n\
-				coral -root				    \\n\
-				deco -root				    \\n\
-				drift -root				    \\n\
--				fadeplot -root				    \\n\
-				galaxy -root				    \\n\
-				goop -root				    \\n\
-				grav -root				    \\n\
-				ifs -root				    \\n\
-  GL: 				jigsaw -root				    \\n\
-				julia -root				    \\n\
--				kaleidescope -root			    \\n\
-  GL: 				moebius -root				    \\n\
-				moire -root				    \\n\
-  GL: 				morph3d -root				    \\n\
-				mountain -root				    \\n\
-				munch -root				    \\n\
-				penrose -root				    \\n\
-  GL: 				pipes -root				    \\n\
-				rdbomb -root				    \\n\
-  GL: 				rubik -root				    \\n\
--				sierpinski -root			    \\n\
-				slip -root				    \\n\
-  GL: 				sproingies -root			    \\n\
-				starfish -root				    \\n\
-				strange -root				    \\n\
-				swirl -root				    \\n\
-				triangle -root				    \\n\
-				xjack -root				    \\n\
-				xlyap -root				    \\n\
-  GL: 				atlantis -root				    \\n\
-				bsod -root				    \\n\
-  GL: 				bubble3d -root				    \\n\
-  GL: 				cage -root				    \\n\
--				crystal -root				    \\n\
-				cynosure -root				    \\n\
-				discrete -root				    \\n\
-				distort -root				    \\n\
-				epicycle -root				    \\n\
-				flow -root				    \\n\
-  GL: 				glplanet -root				    \\n\
-				interference -root			    \\n\
-				kumppa -root				    \\n\
-  GL: 				lament -root				    \\n\
-				moire2 -root				    \\n\
-  GL: 				sonar -root				    \\n\
-  GL: 				stairs -root				    \\n\
-				truchet -root				    \\n\
--				vidwhacker -root			    \\n\
-				blaster -root				    \\n\
-				bumps -root				    \\n\
-				ccurve -root				    \\n\
-				compass -root				    \\n\
-				deluxe -root				    \\n\
--				demon -root				    \\n\
-- GL: 				extrusion -root				    \\n\
--				loop -root				    \\n\
-				penetrate -root				    \\n\
-				petri -root				    \\n\
-				phosphor -root				    \\n\
-  GL: 				pulsar -root				    \\n\
-				ripples -root				    \\n\
-				shadebobs -root				    \\n\
-  GL: 				sierpinski3d -root			    \\n\
-				spotlight -root				    \\n\
-				squiral -root				    \\n\
-				wander -root				    \\n\
--				webcollage -root			    \\n\
-				xflame -root				    \\n\
-				xmatrix -root				    \\n\
-  GL: 				gflux -root				    \\n\
--				nerverot -root				    \\n\
-				xrayswarm -root				    \\n\
-				xspirograph -root			    \\n\
-  GL: 				circuit -root				    \\n\
-  GL: 				dangerball -root			    \\n\
-- GL: 				dnalogo -root				    \\n\
-  GL: 				engine -root				    \\n\
-  GL: 				flipscreen3d -root			    \\n\
-  GL: 				gltext -root				    \\n\
-  GL: 				menger -root				    \\n\
-  GL: 				molecule -root				    \\n\
-				rotzoomer -root				    \\n\
-				scooter -root				    \\n\
-				speedmine -root				    \\n\
-  GL: 				starwars -root				    \\n\
-  GL: 				stonerview -root			    \\n\
-				vermiculate -root			    \\n\
-				whirlwindwarp -root			    \\n\
-				zoom -root				    \\n\
-				anemone -root				    \\n\
-				apollonian -root			    \\n\
-  GL: 				boxed -root				    \\n\
-  GL: 				cubenetic -root				    \\n\
-  GL: 				endgame -root				    \\n\
-				euler2d -root				    \\n\
-				fluidballs -root			    \\n\
-  GL: 				flurry -root				    \\n\
-- GL: 				glblur -root				    \\n\
-  GL: 				glsnake -root				    \\n\
-				halftone -root				    \\n\
-  GL: 				juggler3d -root				    \\n\
-  GL: 				lavalite -root				    \\n\
--				polyominoes -root			    \\n\
-  GL: 				queens -root				    \\n\
-- GL: 				sballs -root				    \\n\
-  GL: 				spheremonics -root			    \\n\
--				thornbird -root				    \\n\
-				twang -root				    \\n\
-- GL: 				antspotlight -root			    \\n\
-				apple2 -root				    \\n\
-  GL: 				atunnel -root				    \\n\
-				barcode -root				    \\n\
-  GL: 				blinkbox -root				    \\n\
-  GL: 				blocktube -root				    \\n\
-  GL: 				bouncingcow -root			    \\n\
-				cloudlife -root				    \\n\
-  GL: 				cubestorm -root				    \\n\
-				eruption -root				    \\n\
-  GL: 				flipflop -root				    \\n\
-  GL: 				flyingtoasters -root			    \\n\
-				fontglide -root				    \\n\
-  GL: 				gleidescope -root			    \\n\
-  GL: 				glknots -root				    \\n\
-  GL: 				glmatrix -root				    \\n\
-- GL: 				glslideshow -root			    \\n\
-  GL: 				hypertorus -root			    \\n\
-- GL: 				jigglypuff -root			    \\n\
-				metaballs -root				    \\n\
-  GL: 				mirrorblob -root			    \\n\
-				piecewise -root				    \\n\
-  GL: 				polytopes -root				    \\n\
-				pong -root				    \\n\
-				popsquares -root			    \\n\
-  GL: 				surfaces -root				    \\n\
-				xanalogtv -root				    \\n\
-				abstractile -root			    \\n\
-				anemotaxis -root			    \\n\
-- GL: 				antinspect -root			    \\n\
-				fireworkx -root				    \\n\
-				fuzzyflakes -root			    \\n\
-				interaggregate -root			    \\n\
-				intermomentary -root			    \\n\
-				memscroller -root			    \\n\
-  GL: 				noof -root				    \\n\
-				pacman -root				    \\n\
-  GL: 				pinion -root				    \\n\
-  GL: 				polyhedra -root				    \\n\
-- GL: 				providence -root			    \\n\
-				substrate -root				    \\n\
-				wormhole -root				    \\n\
-- GL: 				antmaze -root				    \\n\
-  GL: 				boing -root				    \\n\
-				boxfit -root				    \\n\
-  GL: 				carousel -root				    \\n\
-				celtic -root				    \\n\
-  GL: 				crackberg -root				    \\n\
-  GL: 				cube21 -root				    \\n\
-				fiberlamp -root				    \\n\
-  GL: 				fliptext -root				    \\n\
-  GL: 				glhanoi -root				    \\n\
-  GL: 				tangram -root				    \\n\
-  GL: 				timetunnel -root			    \\n\
-  GL: 				glschool -root				    \\n\
-  GL: 				topblock -root				    \\n\
-  GL: 				cubicgrid -root				    \\n\
-				cwaves -root				    \\n\
-  GL: 				gears -root				    \\n\
-  GL: 				glcells -root				    \\n\
-  GL: 				lockward -root				    \\n\
-				m6502 -root				    \\n\
-  GL: 				moebiusgears -root			    \\n\
-  GL: 				voronoi -root				    \\n\
-  GL: 				hypnowheel -root			    \\n\
-  GL: 				klein -root				    \\n\
--				lcdscrub -root				    \\n\
-  GL: 				photopile -root				    \\n\
-  GL: 				skytentacles -root			    \\n\
-  GL: 				rubikblocks -root			    \\n\
-  GL: 				companioncube -root			    \\n\
-  GL: 				hilbert -root				    \\n\
-  GL: 				tronbit -root				    \\n\
-  GL: 				geodesic -root				    \\n\
-				hexadrop -root				    \\n\
-  GL: 				kaleidocycle -root			    \\n\
-  GL: 				quasicrystal -root			    \\n\
-  GL: 				unknownpleasures -root			    \\n\
-				binaryring -root			    \\n\
-  GL: 				cityflow -root				    \\n\
-  GL: 				geodesicgears -root			    \\n\
-  GL: 				projectiveplane -root			    \\n\
-  GL: 				romanboy -root				    \\n\
-				tessellimage -root			    \\n\
-  GL: 				winduprobot -root			    \\n\
-  GL: 				splitflap -root				    \\n\
-  GL: 				cubestack -root				    \\n\
-  GL: 				cubetwist -root				    \\n\
-  GL: 				discoball -root				    \\n\
-  GL: 				dymaxionmap -root			    \\n\
-  GL: 				energystream -root			    \\n\
-  GL: 				hexstrut -root				    \\n\
-  GL: 				hydrostat -root				    \\n\
-  GL: 				raverhoop -root				    \\n\
-  GL: 				splodesic -root				    \\n\
-  GL: 				unicrud -root				    \\n\
-  GL: 				esper -root				    \\n\
-  GL: 				vigilance -root				    \\n\
-  GL: 				crumbler -root				    \\n\
-				filmleader -root			    \\n\
-				glitchpeg -root				    \\n\
-  GL: 				handsy -root				    \\n\
-  GL: 				maze3d -root				    \\n\
-  GL: 				peepers -root				    \\n\
-  GL: 				razzledazzle -root			    \\n\
-				vfeedback -root				    \\n\
-  GL: 				deepstars -root				    \\n\
-  GL: 				gravitywell -root			    \\n\
-  GL: 				beats -root				    \\n\
-  GL: 				covid19 -root				    \\n\
-  GL: 				etruscanvenus -root			    \\n\
-  GL: 				gibson -root				    \\n\
-  GL: 				headroom -root				    \\n\
-  GL: 				sphereeversion -root			    \\n\
-				binaryhorizon -root			    \\n\
-				marbling -root				    \\n\
-  GL: 				chompytower -root			    \\n\
-  GL: 				mapscroller -root			    \\n\
-  GL: 				nakagin -root				    \\n\
-  GL: 				squirtorus -root			    \\n",
+				maze --root				    \\n\
+  GL: 				superquadrics --root			    \\n\
+				attraction --root			    \\n\
+				blitspin --root				    \\n\
+				greynetic --root			    \\n\
+				helix --root				    \\n\
+				hopalong --root				    \\n\
+				imsmap --root				    \\n\
+-				noseguy --root				    \\n\
+-				pyro --root				    \\n\
+				qix --root				    \\n\
+-				rocks --root				    \\n\
+				rorschach --root			    \\n\
+				decayscreen --root			    \\n\
+				flame --root				    \\n\
+				halo --root				    \\n\
+				slidescreen --root			    \\n\
+				pedal --root				    \\n\
+				bouboule --root				    \\n\
+-				braid --root				    \\n\
+				coral --root				    \\n\
+				deco --root				    \\n\
+				drift --root				    \\n\
+-				fadeplot --root				    \\n\
+				galaxy --root				    \\n\
+				goop --root				    \\n\
+				grav --root				    \\n\
+				ifs --root				    \\n\
+  GL: 				jigsaw --root				    \\n\
+				julia --root				    \\n\
+-				kaleidescope --root			    \\n\
+  GL: 				moebius --root				    \\n\
+				moire --root				    \\n\
+  GL: 				morph3d --root				    \\n\
+				mountain --root				    \\n\
+				munch --root				    \\n\
+				penrose --root				    \\n\
+  GL: 				pipes --root				    \\n\
+				rdbomb --root				    \\n\
+  GL: 				rubik --root				    \\n\
+-				sierpinski --root			    \\n\
+				slip --root				    \\n\
+  GL: 				sproingies --root			    \\n\
+				starfish --root				    \\n\
+				strange --root				    \\n\
+				swirl --root				    \\n\
+				triangle --root				    \\n\
+				xjack --root				    \\n\
+				xlyap --root				    \\n\
+  GL: 				atlantis --root				    \\n\
+				bsod --root				    \\n\
+  GL: 				bubble3d --root				    \\n\
+  GL: 				cage --root				    \\n\
+-				crystal --root				    \\n\
+				cynosure --root				    \\n\
+				discrete --root				    \\n\
+				distort --root				    \\n\
+				epicycle --root				    \\n\
+				flow --root				    \\n\
+  GL: 				glplanet --root				    \\n\
+				interference --root			    \\n\
+				kumppa --root				    \\n\
+  GL: 				lament --root				    \\n\
+				moire2 --root				    \\n\
+  GL: 				sonar --root				    \\n\
+  GL: 				stairs --root				    \\n\
+				truchet --root				    \\n\
+-				vidwhacker --root			    \\n\
+-				webcollage --root			    \\n\
+				blaster --root				    \\n\
+				bumps --root				    \\n\
+				ccurve --root				    \\n\
+				compass --root				    \\n\
+				deluxe --root				    \\n\
+-				demon --root				    \\n\
+- GL: 				extrusion --root			    \\n\
+-				loop --root				    \\n\
+				penetrate --root			    \\n\
+				petri --root				    \\n\
+				phosphor --root				    \\n\
+  GL: 				pulsar --root				    \\n\
+				ripples --root				    \\n\
+				shadebobs --root			    \\n\
+  GL: 				sierpinski3d --root			    \\n\
+				spotlight --root			    \\n\
+				squiral --root				    \\n\
+				wander --root				    \\n\
+				xflame --root				    \\n\
+				xmatrix --root				    \\n\
+  GL: 				gflux --root				    \\n\
+-				nerverot --root				    \\n\
+				xrayswarm --root			    \\n\
+				xspirograph --root			    \\n\
+  GL: 				circuit --root				    \\n\
+  GL: 				dangerball --root			    \\n\
+- GL: 				dnalogo --root				    \\n\
+  GL: 				engine --root				    \\n\
+  GL: 				flipscreen3d --root			    \\n\
+  GL: 				gltext --root				    \\n\
+  GL: 				menger --root				    \\n\
+  GL: 				molecule --root				    \\n\
+				rotzoomer --root			    \\n\
+				scooter --root				    \\n\
+				speedmine --root			    \\n\
+  GL: 				starwars --root				    \\n\
+  GL: 				stonerview --root			    \\n\
+				vermiculate --root			    \\n\
+				whirlwindwarp --root			    \\n\
+				zoom --root				    \\n\
+				anemone --root				    \\n\
+				apollonian --root			    \\n\
+  GL: 				boxed --root				    \\n\
+  GL: 				cubenetic --root			    \\n\
+  GL: 				endgame --root				    \\n\
+				euler2d --root				    \\n\
+				fluidballs --root			    \\n\
+  GL: 				flurry --root				    \\n\
+- GL: 				glblur --root				    \\n\
+  GL: 				glsnake --root				    \\n\
+				halftone --root				    \\n\
+  GL: 				juggler3d --root			    \\n\
+  GL: 				lavalite --root				    \\n\
+-				polyominoes --root			    \\n\
+  GL: 				queens --root				    \\n\
+- GL: 				sballs --root				    \\n\
+  GL: 				spheremonics --root			    \\n\
+				twang --root				    \\n\
+- GL: 				antspotlight --root			    \\n\
+				apple2 --root				    \\n\
+  GL: 				atunnel --root				    \\n\
+				barcode --root				    \\n\
+  GL: 				blinkbox --root				    \\n\
+  GL: 				blocktube --root			    \\n\
+  GL: 				bouncingcow --root			    \\n\
+				cloudlife --root			    \\n\
+  GL: 				cubestorm --root			    \\n\
+				eruption --root				    \\n\
+  GL: 				flipflop --root				    \\n\
+  GL: 				flyingtoasters --root			    \\n\
+				fontglide --root			    \\n\
+  GL: 				gleidescope --root			    \\n\
+  GL: 				glknots --root				    \\n\
+  GL: 				glmatrix --root				    \\n\
+- GL: 				glslideshow --root			    \\n\
+  GL: 				hypertorus --root			    \\n\
+- GL: 				jigglypuff --root			    \\n\
+				metaballs --root			    \\n\
+  GL: 				mirrorblob --root			    \\n\
+				piecewise --root			    \\n\
+  GL: 				polytopes --root			    \\n\
+				pong --root				    \\n\
+				popsquares --root			    \\n\
+  GL: 				surfaces --root				    \\n\
+				xanalogtv --root			    \\n\
+				abstractile --root			    \\n\
+				anemotaxis --root			    \\n\
+- GL: 				antinspect --root			    \\n\
+				fireworkx --root			    \\n\
+				fuzzyflakes --root			    \\n\
+				interaggregate --root			    \\n\
+				intermomentary --root			    \\n\
+				memscroller --root			    \\n\
+  GL: 				noof --root				    \\n\
+				pacman --root				    \\n\
+  GL: 				pinion --root				    \\n\
+  GL: 				polyhedra --root			    \\n\
+- GL: 				providence --root			    \\n\
+				substrate --root			    \\n\
+				wormhole --root				    \\n\
+- GL: 				antmaze --root				    \\n\
+  GL: 				boing --root				    \\n\
+				boxfit --root				    \\n\
+  GL: 				carousel --root				    \\n\
+				celtic --root				    \\n\
+  GL: 				crackberg --root			    \\n\
+  GL: 				cube21 --root				    \\n\
+				fiberlamp --root			    \\n\
+  GL: 				fliptext --root				    \\n\
+  GL: 				glhanoi --root				    \\n\
+  GL: 				tangram --root				    \\n\
+  GL: 				timetunnel --root			    \\n\
+  GL: 				glschool --root				    \\n\
+  GL: 				topblock --root				    \\n\
+  GL: 				cubicgrid --root			    \\n\
+				cwaves --root				    \\n\
+  GL: 				gears --root				    \\n\
+  GL: 				glcells --root				    \\n\
+  GL: 				lockward --root				    \\n\
+				m6502 --root				    \\n\
+  GL: 				moebiusgears --root			    \\n\
+  GL: 				voronoi --root				    \\n\
+  GL: 				hypnowheel --root			    \\n\
+  GL: 				klein --root				    \\n\
+-				lcdscrub --root				    \\n\
+  GL: 				photopile --root			    \\n\
+  GL: 				skytentacles --root			    \\n\
+  GL: 				rubikblocks --root			    \\n\
+  GL: 				companioncube --root			    \\n\
+  GL: 				hilbert --root				    \\n\
+  GL: 				tronbit --root				    \\n\
+  GL: 				geodesic --root				    \\n\
+				hexadrop --root				    \\n\
+  GL: 				kaleidocycle --root			    \\n\
+  GL: 				quasicrystal --root			    \\n\
+  GL: 				unknownpleasures --root			    \\n\
+				binaryring --root			    \\n\
+  GL: 				cityflow --root				    \\n\
+  GL: 				geodesicgears --root			    \\n\
+  GL: 				projectiveplane --root			    \\n\
+  GL: 				romanboy --root				    \\n\
+				tessellimage --root			    \\n\
+  GL: 				winduprobot --root			    \\n\
+  GL: 				splitflap --root			    \\n\
+  GL: 				cubestack --root			    \\n\
+  GL: 				cubetwist --root			    \\n\
+  GL: 				discoball --root			    \\n\
+  GL: 				dymaxionmap --root			    \\n\
+  GL: 				energystream --root			    \\n\
+  GL: 				hexstrut --root				    \\n\
+  GL: 				hydrostat --root			    \\n\
+  GL: 				raverhoop --root			    \\n\
+  GL: 				splodesic --root			    \\n\
+  GL: 				unicrud --root				    \\n\
+  GL: 				esper --root				    \\n\
+  GL: 				vigilance --root			    \\n\
+  GL: 				crumbler --root				    \\n\
+				filmleader --root			    \\n\
+				glitchpeg --root			    \\n\
+  GL: 				handsy --root				    \\n\
+  GL: 				maze3d --root				    \\n\
+  GL: 				peepers --root				    \\n\
+  GL: 				razzledazzle --root			    \\n\
+				vfeedback --root			    \\n\
+  GL: 				deepstars --root			    \\n\
+  GL: 				gravitywell --root			    \\n\
+  GL: 				beats --root				    \\n\
+  GL: 				covid19 --root				    \\n\
+  GL: 				etruscanvenus --root			    \\n\
+  GL: 				gibson --root				    \\n\
+  GL: 				headroom --root				    \\n\
+  GL: 				sphereeversion --root			    \\n\
+				binaryhorizon --root			    \\n\
+				marbling --root				    \\n\
+  GL: 				chompytower --root			    \\n\
+  GL: 				hextrail --root				    \\n\
+  GL: 				mapscroller --root			    \\n\
+  GL: 				nakagin --root				    \\n\
+  GL: 				squirtorus --root			    \\n\
+  GL: 				cubocteversion --root			    \\n\
+				droste --root				    \\n\
+  GL: 				papercube --root			    \\n\
+  GL: 				skulloop --root				    \\n\
+  GL: 				highvoltage --root			    \\n\
+  GL: 				kallisti --root				    \\n\
+  GL: 				klondike --root				    \\n\
+  GL: 				dumpsterfire --root			    \\n\
+  GL: 				hopffibration --root			    \\n\
+  GL: 				platonicfolding --root			    \\n",
 "*hacks.antinspect.name:     Ant Inspect",
 "*hacks.antmaze.name:        Ant Maze",
 "*hacks.antspotlight.name:   Ant Spotlight",
@@ -451,11 +460,13 @@
 "*hacks.cubestorm.name:      Cube Storm",
 "*hacks.cubetwist.name:      Cube Twist",
 "*hacks.cubicgrid.name:      Cubic Grid",
+"*hacks.cubocteversion.name: Cuboctahedron Eversion",
 "*hacks.cwaves.name:         C Waves",
 "*hacks.dangerball.name:     Danger Ball",
 "*hacks.decayscreen.name:    Decay Screen",
 "*hacks.deepstars.name:      Deep Stars",
 "*hacks.dnalogo.name:        DNA Logo",
+"*hacks.dumpsterfire.name:   Dumpster Fire",
 "*hacks.dymaxionmap.name:    Dymaxion Map",
 "*hacks.energystream.name:   Energy Stream",
 "*hacks.etruscanvenus.name:  Etruscan Venus",
@@ -487,6 +498,9 @@
 "*hacks.gltext.name:         GL Text",
 "*hacks.gravitywell.name:    Gravity Well",
 "*hacks.hexstrut.name:       Hex Strut",
+"*hacks.hextrail.name:       Hex Trail",
+"*hacks.highvoltage.name:    High Voltage",
+"*hacks.hopffibration.name:  Hopf Fibration",
 "*hacks.ifs.name:            IFS",
 "*hacks.imsmap.name:         IMS Map",
 "*hacks.jigglypuff.name:     Jiggly Puff",
@@ -507,7 +521,9 @@
 "*hacks.nerverot.name:       Nerve Rot",
 "*hacks.noseguy.name:        Nose Guy",
 "*hacks.pacman.name:         Pac-Man",
+"*hacks.papercube.name:      Paper Cube",
 "*hacks.photopile.name:      Photo Pile",
+"*hacks.platonicfolding.name:Platonic Folding",
 "*hacks.popsquares.name:     Pop Squares",
 "*hacks.projectiveplane.name:Projective Plane",
 "*hacks.quasicrystal.name:   Quasi-Crystal",
