@@ -34,8 +34,6 @@
 			"*suppressRotationAnimation: True\n" \
 
 # define release_hydrostat 0
-#undef countof
-#define countof(x) (sizeof((x))/sizeof((*x)))
 
 #include "xlockmore.h"
 #include "colors.h"
@@ -563,13 +561,12 @@ reshape_hydrostat (ModeInfo *mi, int width, int height)
              0.0, 0.0, 0.0,
              0.0, 1.0, 0.0);
 
-# ifdef HAVE_MOBILE	/* Keep it the same relative size when rotated. */
   {
-    int o = (int) current_device_rotation();
-    if (o != 0 && o != 180 && o != -180)
-      glScalef (1/h, 1/h, 1/h);
+    GLfloat s = (MI_WIDTH(mi) < MI_HEIGHT(mi)
+                 ? (MI_WIDTH(mi) / (GLfloat) MI_HEIGHT(mi))
+                 : 1);
+    glScalef (s, s, s);
   }
-# endif
 
   glClear(GL_COLOR_BUFFER_BIT);
 }
@@ -754,7 +751,7 @@ draw_hydrostat (ModeInfo *mi)
   if (!bp->glx_context)
     return;
 
-  glXMakeCurrent(MI_DISPLAY(mi), MI_WINDOW(mi), *(bp->glx_context));
+  glXMakeCurrent(MI_DISPLAY(mi), MI_WINDOW(mi), *bp->glx_context);
 
   glClear(GL_COLOR_BUFFER_BIT | GL_DEPTH_BUFFER_BIT);
 
@@ -797,11 +794,21 @@ free_hydrostat (ModeInfo *mi)
 {
   hydrostat_configuration *bp = &bps[MI_SCREEN(mi)];
   int i;
-  if (!bp->squids)
-    return;
-  for (i = 0; i < MI_COUNT(mi); i++)
-    free_squid (bp->squids[i]);
-  free (bp->squids);
+
+  if (!bp->glx_context) return;
+  glXMakeCurrent(MI_DISPLAY(mi), MI_WINDOW(mi), *bp->glx_context);
+
+# ifdef USE_TRACKBALL
+  if (bp->trackball) gltrackball_free (bp->trackball);
+# endif
+  if (bp->squids)
+    {
+      for (i = 0; i < MI_COUNT(mi); i++)
+        free_squid (bp->squids[i]);
+      free (bp->squids);
+    }
+
+  if (glIsList(bp->head)) glDeleteLists(bp->head, 1);
 }
 
 XSCREENSAVER_MODULE ("Hydrostat", hydrostat)
