@@ -25,8 +25,6 @@
 			"*suppressRotationAnimation: True\n" \
 
 # define release_quasicrystal 0
-#undef countof
-#define countof(x) (sizeof((x))/sizeof((*x)))
 
 #include "xlockmore.h"
 #include "colors.h"
