@@ -22,7 +22,7 @@ static const char sccsid[] = "@(#)sproingiewrap.c	4.07 97/11/24 xlockmore";
  *
  *    Programming:  Ed Mackey, http://www.netaxs.com/~emackey/
  *                  Gordon Wrigley, gdw33@student.canterbury.ac.nz
- *                  Sergio Gutirrez "Sergut", sergut@gmail.com
+ *                  Sergio Gutiérrez "Sergut", sergut@gmail.com
  *    Sproingie 3D objects modeled by:  Al Mackey, al@iam.com
  *       (using MetaNURBS in NewTek's Lightwave 3D v5).
  *
@@ -53,7 +53,6 @@ static const char sccsid[] = "@(#)sproingiewrap.c	4.07 97/11/24 xlockmore";
 					"*fpsTop:       True    \n"			\
 					"*wireframe:	False	\n"
 
-# define refresh_sproingies 0
 # define release_sproingies 0
 # define sproingies_handle_event 0
 # include "xlockmore.h"				/* from the xscreensaver distribution */
@@ -67,9 +66,6 @@ static const char sccsid[] = "@(#)sproingiewrap.c	4.07 97/11/24 xlockmore";
 
 #include "sproingies.h"
 
-#undef countof
-#define countof(x) (sizeof((x))/sizeof((*x)))
-
 static XrmOptionDescRec opts[] = {
     {"-fall",     ".smartSproingies",  XrmoptionNoArg,  "False"},
     {"-no-fall",  ".smartSproingies",  XrmoptionNoArg,  "True"},
@@ -87,7 +83,7 @@ ENTRYPOINT ModeSpecOpt sproingies_opts =
 #ifdef USE_MODULES
 ModStruct   sproingies_description =
 {"sproingies", "init_sproingies", "draw_sproingies", NULL,
- "refresh_sproingies", "init_sproingies", NULL, &sproingies_opts,
+ "refresh_sproingies", "init_sproingies", "free_sproingies", &sproingies_opts,
  1000, 5, 0, 400, 4, 1.0, "",
  "Shows Sproingies!  Nontoxic.  Safe for pets and small children", 0, NULL};
 
@@ -112,9 +108,6 @@ typedef struct {
 static sproingiesstruct *sproingies = NULL;
 
 
-static void free_sproingies (ModeInfo * mi);
-
-
 ENTRYPOINT void
 init_sproingies (ModeInfo * mi)
 {
@@ -127,7 +120,7 @@ init_sproingies (ModeInfo * mi)
 	sproingiesstruct *sp;
 	int         wfmode = 0, grnd = 0, mspr, w, h;
 
-	MI_INIT (mi, sproingies, free_sproingies);
+	MI_INIT (mi, sproingies);
 	sp = &sproingies[screen];
 
 	sp->mono = (MI_IS_MONO(mi) ? 1 : 0);
@@ -185,7 +178,7 @@ draw_sproingies (ModeInfo * mi)
 		return;
 
 	glDrawBuffer(GL_BACK);
-	glXMakeCurrent(display, window, *(sp->glx_context));
+	glXMakeCurrent(display, window, *sp->glx_context);
 
     glPushMatrix();
     glRotatef(current_device_rotation(), 0, 0, 1);
@@ -216,16 +209,13 @@ reshape_sproingies (ModeInfo *mi, int w, int h)
 }
 
 
-static void
+ENTRYPOINT void
 free_sproingies (ModeInfo * mi)
 {
 	sproingiesstruct *sp = &sproingies[MI_SCREEN(mi)];
-
-	if (sp->glx_context) {
-
-		glXMakeCurrent(MI_DISPLAY(mi), sp->window, *(sp->glx_context));
-		CleanupSproingies(&sp->si);
-	}
+    if (!sp->glx_context) return;
+	glXMakeCurrent (MI_DISPLAY(mi), MI_WINDOW(mi), *sp->glx_context);
+    CleanupSproingies(&sp->si);
 }
 
 XSCREENSAVER_MODULE ("Sproingies", sproingies)
