@@ -13,10 +13,7 @@
                         "*showFPS:      False              \n" \
 			"*suppressRotationAnimation: True\n" \
 
-# define free_voronoi 0
 # define release_voronoi 0
-#undef countof
-#define countof(x) (sizeof((x))/sizeof((*x)))
 
 #define BELLRAND(n) ((frand((n)) + frand((n)) + frand((n))) / 3)
 
@@ -340,7 +337,7 @@ reshape_voronoi (ModeInfo *mi, int width, int height)
     int rot = current_device_rotation();
 
     glTranslatef (0.5, 0.5, 0);
-    //  glScalef(0.19, 0.19, 0.19);
+    /* glScalef(0.19, 0.19, 0.19); */
 
     if (rot == 180 || rot == -180) {
       glTranslatef (1, 1, 0);
@@ -514,7 +511,7 @@ draw_voronoi (ModeInfo *mi)
   if (!vp->glx_context)
     return;
 
-  glXMakeCurrent(MI_DISPLAY(mi), MI_WINDOW(mi), *(vp->glx_context));
+  glXMakeCurrent(MI_DISPLAY(mi), MI_WINDOW(mi), *vp->glx_context);
 
   glShadeModel(GL_FLAT);
   glEnable(GL_POINT_SMOOTH);
@@ -538,6 +535,23 @@ draw_voronoi (ModeInfo *mi)
   glXSwapBuffers(dpy, window);
 }
 
+
+ENTRYPOINT void
+free_voronoi (ModeInfo *mi)
+{
+  voronoi_configuration *vp = &vps[MI_SCREEN(mi)];
+  node *n;
+  if (!vp->glx_context) return;
+  glXMakeCurrent(MI_DISPLAY(mi), MI_WINDOW(mi), *vp->glx_context);
+  if (vp->colors) free (vp->colors);
+  n = vp->nodes;
+  while (n) {
+    node *n2 = n->next;
+    free (n);
+    n = n2;
+  }
+}
+
 XSCREENSAVER_MODULE ("Voronoi", voronoi)
 
 #endif /* USE_GL */
